summaryrefslogtreecommitdiff
path: root/locale.c
diff options
context:
space:
mode:
authorKarl Williamson <khw@cpan.org>2017-08-28 17:43:29 -0600
committerKarl Williamson <khw@cpan.org>2017-11-08 20:52:52 -0700
commit5792c6421a2dffa32c7169e0ebe482427b43a1b8 (patch)
tree3cda7b92afd3c9f442374b0898dbdfdbb40bd24b /locale.c
parent892e646556f1997b0384dc508d3223c2c2a7be74 (diff)
downloadperl-5792c6421a2dffa32c7169e0ebe482427b43a1b8.tar.gz
Change name of internal function
Following on the previous commit, this changes the name of the function that changes the variable to be in sync with it.
Diffstat (limited to 'locale.c')
-rw-r--r--locale.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/locale.c b/locale.c
index 36522ee267..4d93217fc8 100644
--- a/locale.c
+++ b/locale.c
@@ -201,8 +201,8 @@ Perl_new_numeric(pTHX_ const char *newnum)
* It installs this locale as the current underlying default.
*
* The default locale and the C locale can be toggled between by use of the
* set_numeric_local() and set_numeric_standard() functions, which should
* probably not be called directly, but only via macros like
* SET_NUMERIC_STANDARD() in perl.h.
*
* The toggling is necessary mainly so that a non-dot radix decimal point
@@ -289,7 +289,7 @@ Perl_set_numeric_standard(pTHX)
}
void
-Perl_set_numeric_local(pTHX)
+Perl_set_numeric_underlying(pTHX)
{
#ifdef USE_LOCALE_NUMERIC
@@ -201,8 +201,8 @@ Perl_new_numeric(pTHX_ const char *newnum)
*
* The default locale and the C locale can be toggled between by use of the
- * set_numeric_local() and set_numeric_standard() functions, which should
- * probably not be called directly, but only via macros like
+ * set_numeric_underlying() and set_numeric_standard() functions, which
+ * should probably not be called directly, but only via macros like
* SET_NUMERIC_STANDARD() in perl.h.
*